<?php
/**
 * Sets up the theme and provides some helper functions. Some helper functions
 * are used in the theme as custom template tags. Others are attached to action and
 * filter hooks in WordPress to change core functionality.
 * For more information on hooks, actions, and filters, see https://codex.wordpress.org/ 
 */

 
/*********************************************************************************************************
* Basic
**********************************************************************************************************/

	function seoswhite_add_editor_styles() {
			add_editor_style( get_template_directory_uri() . '/style.css' );
		}

		if ( ! isset( $content_width ) ) $content_width = 600;
		
		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
	
	function seoswhite_setup() {
		add_action( 'admin_init', 'seoswhite_add_editor_styles' );
		add_theme_support('title-tag');
		add_theme_support('automatic-feed-links');
		add_theme_support('post-thumbnails');
		add_theme_support( 'html5', array( 'comment-list', 'comment-form', 'search-form', 'gallery', 'caption' ) );
	}

	add_action( 'after_setup_theme', 'seoswhite_setup' );
		
/*********************************************************************************************************
* Register Sidebar
**********************************************************************************************************/

	function seoswhite_widgets_init() {

		register_sidebar( array(
			'id'          => ('left'),
			'name'        => __( 'left', 'seos-white' ),
			 'description' => __( 'This sidebar is left of content.', 'seos-white' ),
		) );

	}

		add_action( 'widgets_init', 'seoswhite_widgets_init' );

/*********************************************************************************************************
* Register Nav Menu
**********************************************************************************************************/

		register_nav_menus(array(
			'menu-top' => __('Menu top', 'seos-white')
		));

/*********************************************************************************************************
* Pagination. 
**********************************************************************************************************/

		add_filter('wp_link_pages_args','seoswhite_add_next_and_number');

		function seoswhite_add_next_and_number($args){
			if($args['next_or_number'] == 'next_and_number'){
				global $page, $numpages, $multipage, $more, $pagenow;
				$args['next_or_number'] = 'number';
				$prev = '';
				$next = '';
				if ( $multipage ) {
					if ( $more ) {
						$i = $page - 1;
						if ( $i && $more ) {
							$prev .= _wp_link_page($i);
							$prev .= $args['link_before']. $args['previouspagelink'] . $args['link_after'] . '</a>';
						}
						$i = $page + 1;
						if ( $i <= $numpages && $more ) {
							$next .= _wp_link_page($i);
							$next .= $args['link_before']. $args['nextpagelink'] . $args['link_after'] . '</a>';
						}
					}
				}
				$args['before'] = $args['before'].$prev;
				$args['after'] = $next.$args['after'];    
			}
			return $args;
		}
		
/*********************************************************************************************************
* Load CSS
**********************************************************************************************************/

		function seoswhite_css() {		   
				wp_enqueue_style('seoswhite_style', get_stylesheet_uri());
			}

		add_action('wp_enqueue_scripts', 'seoswhite_css');
		
		function seoswhite_google_fonts() {
				wp_enqueue_style( 'seos-white-google-fonts', '//fonts.googleapis.com/css?family=Roboto:900', false ); 
			}

		add_action( 'wp_enqueue_scripts', 'seoswhite_google_fonts' );

/*********************************************************************************************************
* Custom header
**********************************************************************************************************/

		$seoswhite_custom_header_logo  = array(
			'width'         => 1300,
			'height'        => 100,
			'random-default' => true,
			'flex-height'            => true,
			'flex-width'             => false,
			'header-text'            => false,
		);

		add_theme_support( 'custom-header', $seoswhite_custom_header_logo );

/*********************************************************************************************************
* Custom Colors Customize
**********************************************************************************************************/

		function seoswhite_colors($wp_customize) {

/********************************************
* Hover color
*********************************************/
    
		$wp_customize->add_setting('seoswhite_hover_color', array(        
  	    'default' => '#777',
		'sanitize_callback' => 'sanitize_hex_color'
  	  ));  
	
		$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'seoswhite_hover_color', array(
		'label' => __('Hover Color', 'seos-white'),       
  	    'section' => 'colors',
  	    'settings' => 'seoswhite_hover_color'
  	  )));

/********************************************
* Header Color
*********************************************/ 
 
		$wp_customize->add_setting('seoswhite_header_color', array(         
		'default'     => '#FFFFFF',
		'sanitize_callback' => 'sanitize_hex_color'
		)); 

		$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'seoswhite_header_color', array(
		'label' => __('Header Color', 'seos-white'),        
		'section' => 'colors',
		'settings' => 'seoswhite_header_color'
		)));

/********************************************
* Nav Hover Color
*********************************************/ 
 
		$wp_customize->add_setting('seoswhite_nav_hover_color', array(         
		'default'     => '#FFFFFF',
		'sanitize_callback' => 'sanitize_hex_color'
		)); 	

		$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'seoswhite_nav_hover_color', array(
		'label' => __('Nav Hover Color', 'seos-white'),        
		'section' => 'colors',
		'settings' => 'seoswhite_nav_hover_color'
		)));
	
/********************************************
* Main Background
*********************************************/ 
	
		$wp_customize->add_setting('seoswhite_main_background_color', array(         
		'default'     => '#FFFFFF',
		'sanitize_callback' => 'sanitize_hex_color'
		)); 	

		$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'seoswhite_main_background_color', array(
		'label' => __('Main Background Color', 'seos-white'),        
		'section' => 'colors',
		'settings' => 'seoswhite_main_background_color'
		)));
	
/********************************************
* Footer Background
*********************************************/ 
	
		$wp_customize->add_setting('seoswhite_footer_background_color', array(         
		'default'     => '#333',
		'sanitize_callback' => 'sanitize_hex_color'
		)); 	

		$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'seoswhite_footer_background_color', array(
		'label' => __('Footer Background Color', 'seos-white'),        
		'section' => 'colors',
		'settings' => 'seoswhite_footer_background_color'
		)));
}
		add_action('customize_register', 'seoswhite_colors');	
?><?php
		function seoswhite_customize_css() {
    ?>
		<style type="text/css">
		header, header p, header h1 {color:<?php echo esc_html(get_theme_mod('seoswhite_header_color')); ?>;}   
		a:hover, details a:hover, article h1:hover {color:<?php echo esc_html(get_theme_mod('seoswhite_hover_color')); ?>;}
		 nav ul ul li a:hover {color:<?php echo esc_html(get_theme_mod('seoswhite_nav_hover_color')); ?>;}     
		main {background:<?php echo esc_html(get_theme_mod('seoswhite_main_background_color')); ?>;}     
 		footer {background:<?php echo esc_html(get_theme_mod('seoswhite_footer_background_color')); ?>;}
 		.option-con {border:<?php echo esc_html(get_theme_mod('seoswhite_footer_background_color')); ?>;}    
		</style>
    <?php	
}
		add_action('wp_head', 'seoswhite_customize_css');

/*********************************************************************************************************
* Custom Background Color
**********************************************************************************************************/

		$custom_background = array(
			'default-color'          => 'FFFFFF',
			'wp-head-callback'       => '_custom_background_cb',
		);
		add_theme_support( 'custom-background', $custom_background );
			
/*********************************************************************************************************
* Excerpt
**********************************************************************************************************/

		function seoswhite_new_excerpt_more( $more ) {
			return ' <a class="read-more" href="'. get_permalink( get_the_ID() ) . '">' . __('Read More', 'seos-white') . '</a>';
		}
			add_filter( 'excerpt_more', 'seoswhite_new_excerpt_more' );

		function seoswhite_custom_excerpt_length( $length ) {
			return 50;
		}
		add_filter( 'excerpt_length', 'seoswhite_custom_excerpt_length', 999 );
			
/*********************************************************************************************************
* Include
**********************************************************************************************************/

	require get_template_directory() . '/inc/customizer.php';
	require get_template_directory() . '/inc/social.php';
